/*
 * Copyright 2016 Nekhelesh Ramananthan <nik90@ubuntu.com>
 *
 * This file is part of Flashback.
 *
 * Podbird is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * Podbird is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Window 2.2
import Qt.labs.settings 1.0
import Ubuntu.Components 1.3

import "components"

Window {
    id: flashbackRootWindow

    title: "Flashback"

    width: units.gu(150)
    height: units.gu(100)

    // Set minimum dimension below which design breaks
    minimumWidth: units.gu(60)
    minimumHeight: units.gu(80)

    // Set maximum dimension to avoid excessive white space
    maximumHeight: units.gu(100)
    maximumWidth: units.gu(150)

    MainView {
        id: mainView

        objectName: "mainView"
        applicationName: "flashback.nik90"

        width: parent.width
        height: parent.height

        Settings {
            id: flashbackAccountSettings
            category: "AccountSettings"
            property string refresh_token: ""
            property string access_token: ""
            property int token_expiry: 0
        }

        AdaptivePageLayout {
            id: apl

            primaryPage: mainPage
            anchors.fill: parent

            layouts:[
                PageColumnsLayout {
                    id: mobileLayout

                    when: width < units.gu(125)

                    // Main Column
                    PageColumn {
                        fillWidth: true
                    }
                },

                PageColumnsLayout {
                    id: tabletLayout

                    when: width >= units.gu(125)

                    // Left Column Sidebar
                    PageColumn {
                        minimumWidth: units.gu(30)
                        maximumWidth: units.gu(125)
                        preferredWidth: units.gu(50)
                    }

                    // Content Column
                    PageColumn {
                        fillWidth: true
                    }
                }
            ]

            Page {
                id: mainPage
                header: FlashbackHeader {
                    id: pageHeader
                    title: i18n.tr("Flashback")

                    trailingActionBar.actions: Action {
                        iconName: "settings"
                        onTriggered: apl.addPageToCurrentColumn(apl.primaryPage, Qt.resolvedUrl("ui/SettingsPage.qml"))
                    }

                    extension: FlashbackPageSection {
                        anchors { left: parent.left; right: parent.right; bottom: parent.bottom }
                        model: [i18n.tr("Movies")]
                    }
                }
            }
        }
    }
}

