/*
 * Copyright 2016 Nekhelesh Ramananthan <nik90@ubuntu.com>
 *
 * This file is part of Flashback.
 *
 * Podbird is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * Podbird is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import Ubuntu.Web 0.2
import Ubuntu.Components 1.3

import "../backend/localdb.js" as LocalDb
import "../backend/scripts.js" as Scripts
import "../components"

Page {
    id: oauthPage

    header: FlashbackHeader {
        title: i18n.tr("Log In and Authorize Trakt Account")
    }

    WebContext {
        id: webcontext
        userAgent: "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:45.0) Gecko/20100101 Firefox/46.0"
    }

    WebView {
        id: webView

        anchors { top: oauthPage.header.bottom; left: parent.left; right: parent.right; bottom: parent.bottom }

        context: webcontext
        incognito: true
        preferences.localStorageEnabled: true
        preferences.allowFileAccessFromFileUrls: true
        preferences.allowUniversalAccessFromFileUrls: true
        preferences.appCacheEnabled: true
        preferences.javascriptCanAccessClipboard: true

        url: "https://trakt.tv/oauth/authorize?client_id=%1&redirect_uri=%2&response_type=code".arg(Scripts.credentials.client_id).arg(encodeURIComponent(Scripts.credentials.redirect_uri))

        onUrlChanged: {
            if (url.toString().substring(0, 26) === Scripts.credentials.redirect_uri) {
                var code = url.toString().substring(32, url.toString().length)
                Scripts.get_access_token(code);
            }
        }

        onLoadingChanged: {
            if (webView.lastLoadFailed) {
                console.log("[ERROR]: Trakt app authentication page failed to load.")
                apl.removePages(oauthPage)
            }
        }
    }

    ProgressBar {
        height: units.gu(0.5)
        visible: webView.loading
        value: webView.loadProgress
        showProgressPercentage: false
        minimumValue: 0; maximumValue: 100
        anchors { top: oauthPage.header.bottom; left: parent.left; right: parent.right }
    }
}

