/*
 * Flashback - Entertainment app for Ubuntu
 * Copyright (C) 2013-2016 Nekhelesh Ramananthan <nik90@ubuntu.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import "../components"

Page {
    id: traktPage

    header: FlashbackHeader {
        title: i18n.tr("Trakt Account")
        flickable: flickable
    }

    Flickable {
        id: flickable

        anchors.fill: parent
        contentHeight: detailsColumn.height
        interactive: contentHeight > parent.height

        Column {
            id: detailsColumn

            spacing: units.gu(4)
            anchors { left: parent.left; right: parent.right; top: parent.top; margins: units.gu(2) }

            Image {
                id: traktLogo
                height: units.gu(25)
                fillMode: Image.PreserveAspectFit
                source: "../graphics/trakt.png"
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Label {
                width: parent.width
                textSize: Label.Large
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                text: i18n.tr("Track what you're watching. Discover new shows & movies.")
            }

            Label {
                width: parent.width
                wrapMode: Text.WordWrap
                //horizontalAlignment: Text.AlignHCenter
                text: i18n.tr("Trakt is a platform that helps you keep track of TV shows and movies you watch. It integrates with your media center or home theater PC to enable scrobbling, so everything is automatic. \
                       \n\nBy authenticating into Trakt, you get the following additional features.\n\n - Check-in and rate movies\n - Keep track of watched movies
 - Get personalized recommendations for new movies and TV shows\n - Add movies to your watchlist\n - Keep data synced across devices using Trakt")
            }

            Button {
                width: parent.width / 2
                height: units.gu(6)
                enabled: !flashbackAccountSettings.access_token
                text: flashbackAccountSettings.access_token ? i18n.tr("Logged In") : i18n.tr("Log in")
                color: UbuntuColors.green
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: apl.addPageToCurrentColumn(traktPage, Qt.resolvedUrl("OAuth.qml"))
            }
        }
    }
}
